==> nonebot_plugin_resolver2-1.4.6.tar.gz: nonebot_plugin_resolver2-1.4.6/nonebot_plugin_resolver2/matchers/twitter.py <==
import re, httpx, asyncio

from nonebot import on_keyword
from nonebot.rule import Rule
from nonebot.adapters.onebot.v11 import Message, MessageEvent, Bot, MessageSegment
from nonebot import logger

from .filter import is_not_in_disable_group
from .utils import get_video_seg
from ..constant import COMMON_HEADER, GENERAL_REQ_LINK
from ..data_source.common import download_img, download_video

from ..config import *

twitter = on_keyword(keywords={"x.com"}, rule = Rule(is_not_in_disable_group))

@twitter.handle()
async def _(bot: Bot, event: MessageEvent):

    msg: str = event.message.extract_plain_text().strip()

    x_url = re.search(r"https?:\/\/x.com\/[0-9-a-zA-Z_]{1,20}\/status\/([0-9]*)", msg)[0]

    x_url = GENERAL_REQ_LINK.replace("{}", x_url)

    # 内联一个请求
    async def x_req(url):
        async with httpx.AsyncClient() as client:
            return await client.get(url, headers={
                'Accept': 'ext/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,'
                          'application/signed-exchange;v=b3;q=0.7',
                'Accept-Encoding': 'gzip, deflate',
                'Accept-Language': 'zh-CN,zh;q=0.9',
                'Host': '47.99.158.118',
                'Proxy-Connection': 'keep-alive',
                'Upgrade-Insecure-Requests': '1',
                'Sec-Fetch-User': '?1',
                **COMMON_HEADER
            })
    resp = await x_req(x_url)
    x_data: object = resp.json()['data']

    
    if x_data is None:
        x_url = x_url + '/photo/1'
        resp = await x_req(x_url)
        x_data = resp.json()['data']

    x_url_res = x_data['url']

    await twitter.send(Message(f"{NICKNAME}识别 | X"))

    seg: MessageSegment = None
    # 图片
    if x_url_res.endswith(".jpg") or x_url_res.endswith(".png"):
        img_name = await download_img(url = x_url_res, proxy = PROXY)
        seg = MessageSegment.image(plugin_cache_dir / img_name)
    else:
        # 视频
        video_name = await download_video(x_url_res, proxy=PROXY)
        seg = await get_video_seg(file_name = video_name)
    if seg:
        await twitter.send(seg)

==> nonebot_plugin_resolver2-1.4.8.tar.gz: nonebot_plugin_resolver2-1.4.8/nonebot_plugin_resolver2/matchers/twitter.py <==
import re, httpx, asyncio

from nonebot import on_keyword
from nonebot.rule import Rule
from nonebot.adapters.onebot.v11 import Message, MessageEvent, Bot, MessageSegment
from nonebot import logger

from .filter import is_not_in_disable_group
from .utils import get_video_seg, make_node_segment
from ..constant import COMMON_HEADER, GENERAL_REQ_LINK
from ..data_source.common import download_img, download_video

from ..config import *

twitter = on_keyword(keywords={"x.com"}, rule = Rule(is_not_in_disable_group))

@twitter.handle()
async def _(bot: Bot, event: MessageEvent):

    msg: str = event.message.extract_plain_text().strip()

    x_url = re.search(r"https?:\/\/x.com\/[0-9-a-zA-Z_]{1,20}\/status\/([0-9]*)", msg)[0]

    x_url = GENERAL_REQ_LINK.replace("{}", x_url)

    # 内联一个请求
    async def x_req(url):
        async with httpx.AsyncClient() as client:
            return await client.get(url, headers={
                'Accept': 'ext/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,'
                          'application/signed-exchange;v=b3;q=0.7',
                'Accept-Encoding': 'gzip, deflate',
                'Accept-Language': 'zh-CN,zh;q=0.9',
                'Host': '47.99.158.118',
                'Proxy-Connection': 'keep-alive',
                'Upgrade-Insecure-Requests': '1',
                'Sec-Fetch-User': '?1',
                **COMMON_HEADER
            })
    resp = await x_req(x_url)
    x_data: object = resp.json()['data']

    await twitter.send(Message(f"{NICKNAME}解析 | X"))
    
    if x_data is not None:
        x_video_url = x_data['url']
        video_name = await download_video(x_video_url, proxy=PROXY)
        seg = await get_video_seg(file_name = video_name)
        await twitter.send(seg)
    else:
        resp = await x_req(f"{x_url}/photo")
        # logger.info(f"url:{x_pic_url}, res:{resp}")
        x_pic_url = resp.json()['data']['url']
        img_name = await download_img(url = x_pic_url, proxy = PROXY)
        await twitter.send(MessageSegment.image(plugin_cache_dir / img_name))
